@@ -12,8 +12,8 @@ from globus_sdk.authorizers import (
     RefreshTokenAuthorizer,
 )
 from globus_sdk.services.auth import OAuthTokenResponse
-from globus_sdk.tokenstorage import ValidatingTokenStorage
-from globus_sdk.tokenstorage.v2.validating_token_storage import MissingTokenError
+from globus_sdk.token_storage import ValidatingTokenStorage
+from globus_sdk.token_storage.validating_token_storage import MissingTokenError
 
 GA = t.TypeVar("GA", bound=GlobusAuthorizer)
 
@@ -28,7 +28,7 @@ class AuthorizerFactory(
     authorization requirements used to initialize the ``ValidatingTokenStorage``.
 
     An ``AuthorizerFactory`` keeps a cache of authorizer objects that are
-    re-used until its ``store_token_response`` method is called.
+    reused until its ``store_token_response`` method is called.
     """
 
     def __init__(self, token_storage: ValidatingTokenStorage) -> None:
