@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import typing as t
+import uuid
 
 from globus_sdk import (
     AuthClient,
@@ -10,10 +11,9 @@ from globus_sdk import (
     NativeAppAuthClient,
     Scope,
 )
-from globus_sdk._types import ScopeCollectionType, UUIDLike
 from globus_sdk.gare import GlobusAuthorizationParameters
 from globus_sdk.login_flows import CommandLineLoginFlowManager, LoginFlowManager
-from globus_sdk.tokenstorage import (
+from globus_sdk.token_storage import (
     HasRefreshTokensValidator,
     NotExpiredValidator,
     TokenStorage,
@@ -78,9 +78,11 @@ class UserApp(GlobusApp):
         app_name: str = "Unnamed Globus App",
         *,
         login_client: AuthLoginClient | None = None,
-        client_id: UUIDLike | None = None,
+        client_id: uuid.UUID | str | None = None,
         client_secret: str | None = None,
-        scope_requirements: t.Mapping[str, ScopeCollectionType] | None = None,
+        scope_requirements: (
+            t.Mapping[str, str | Scope | t.Iterable[str | Scope]] | None
+        ) = None,
         config: GlobusAppConfig = DEFAULT_CONFIG,
     ) -> None:
         super().__init__(
@@ -127,7 +129,7 @@ class UserApp(GlobusApp):
         self,
         app_name: str,
         config: GlobusAppConfig,
-        client_id: UUIDLike,
+        client_id: uuid.UUID | str,
         client_secret: str | None,
     ) -> AuthLoginClient:
         if client_secret:
