@@ -1,15 +1,26 @@
 from __future__ import annotations
 
 import logging
+import sys
 import typing as t
+import uuid
 
-from globus_sdk import GlobusHTTPResponse, client, paging, utils
-from globus_sdk._types import UUIDLike
+from globus_sdk import GlobusHTTPResponse, client, paging
+from globus_sdk._internal import guards
+from globus_sdk._internal.remarshal import commajoin
+from globus_sdk._missing import MISSING, MissingType
 from globus_sdk.authorizers import GlobusAuthorizer
 from globus_sdk.globus_app import GlobusApp
-from globus_sdk.scopes import FlowsScopes, Scope, ScopeBuilder, SpecificFlowScopeBuilder
-from globus_sdk.utils import MISSING, MissingType
+from globus_sdk.scopes import (
+    FlowsScopes,
+    GCSCollectionScopes,
+    Scope,
+    SpecificFlowScopes,
+    TransferScopes,
+)
+from globus_sdk.transport import RequestsTransport, RetryConfig
 
+from .data import RunActivityNotificationPolicy
 from .errors import FlowsAPIError
 from .response import (
     IterableFlowsResponse,
@@ -17,6 +28,11 @@ from .response import (
     IterableRunsResponse,
 )
 
+if sys.version_info >= (3, 11):
+    from typing import Self
+else:
+    from typing_extensions import Self
+
 log = logging.getLogger(__name__)
 
 
@@ -32,20 +48,22 @@ class FlowsClient(client.BaseClient):
     error_class = FlowsAPIError
     service_name = "flows"
     scopes = FlowsScopes
-    default_scope_requirements = [Scope(FlowsScopes.all)]
+    default_scope_requirements = [FlowsScopes.all]
 
     def create_flow(
         self,
         title: str,
         definition: dict[str, t.Any],
         input_schema: dict[str, t.Any],
-        subtitle: str | None = None,
-        description: str | None = None,
-        flow_viewers: list[str] | None = None,
-        flow_starters: list[str] | None = None,
-        flow_administrators: list[str] | None = None,
-        keywords: list[str] | None = None,
-        subscription_id: UUIDLike | None = None,
+        subtitle: str | MissingType = MISSING,
+        description: str | MissingType = MISSING,
+        flow_viewers: list[str] | MissingType = MISSING,
+        flow_starters: list[str] | MissingType = MISSING,
+        flow_administrators: list[str] | MissingType = MISSING,
+        run_managers: list[str] | MissingType = MISSING,
+        run_monitors: list[str] | MissingType = MISSING,
+        keywords: list[str] | MissingType = MISSING,
+        subscription_id: uuid.UUID | str | None | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
         """
@@ -108,6 +126,30 @@ class FlowsClient(client.BaseClient):
                         "urn:globus:groups:id:c1dcd951-3f35-4ea3-9f28-a7cdeaf8b68f"
                     ]
 
+        :param run_managers: A set of Principal URN values indicating entities who can
+            perform management operations on the flow's *runs*.
+
+            .. dropdown:: Example Values
+
+                .. code-block:: json
+
+                    [
+                        "urn:globus:auth:identity:b44bddda-d274-11e5-978a-9f15789a8150",
+                        "urn:globus:groups:id:c1dcd951-3f35-4ea3-9f28-a7cdeaf8b68f"
+                    ]
+
+        :param run_monitors: A set of Principal URN values indicating entities who can
+            monitor the flow's *runs*.
+
+            .. dropdown:: Example Values
+
+                .. code-block:: json
+
+                    [
+                        "urn:globus:auth:identity:b44bddda-d274-11e5-978a-9f15789a8150",
+                        "urn:globus:groups:id:c1dcd951-3f35-4ea3-9f28-a7cdeaf8b68f"
+                    ]
+
         :param keywords: A set of terms used to categorize the flow used in query and
             discovery operations (0 - 1024 items)
         :param subscription_id: The ID of the subscription to associate with the flow,
@@ -152,28 +194,25 @@ class FlowsClient(client.BaseClient):
         """  # noqa E501
 
         data = {
-            k: v
-            for k, v in {
-                "title": title,
-                "definition": definition,
-                "input_schema": input_schema,
-                "subtitle": subtitle,
-                "description": description,
-                "flow_viewers": flow_viewers,
-                "flow_starters": flow_starters,
-                "flow_administrators": flow_administrators,
-                "keywords": keywords,
-                "subscription_id": subscription_id,
-            }.items()
-            if v is not None
+            "title": title,
+            "definition": definition,
+            "input_schema": input_schema,
+            "subtitle": subtitle,
+            "description": description,
+            "flow_viewers": flow_viewers,
+            "flow_starters": flow_starters,
+            "flow_administrators": flow_administrators,
+            "run_managers": run_managers,
+            "run_monitors": run_monitors,
+            "keywords": keywords,
+            "subscription_id": subscription_id,
+            **(additional_fields or {}),
         }
-        data.update(additional_fields or {})
-
         return self.post("/flows", data=data)
 
     def get_flow(
         self,
-        flow_id: UUIDLike,
+        flow_id: uuid.UUID | str,
         *,
         query_params: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
@@ -191,45 +230,42 @@ class FlowsClient(client.BaseClient):
                     :service: flows
                     :ref: Flows/paths/~1flows~1{flow_id}/get
         """
-
-        if query_params is None:
-            query_params = {}
-
         return self.get(f"/flows/{flow_id}", query_params=query_params)
 
     @paging.has_paginator(paging.MarkerPaginator, items_key="flows")
     def list_flows(
         self,
         *,
-        filter_role: str | None = None,
-        filter_fulltext: str | None = None,
-        orderby: str | t.Iterable[str] | None = None,
-        marker: str | None = None,
+        filter_roles: str | t.Iterable[str] | MissingType = MISSING,
+        filter_fulltext: str | MissingType = MISSING,
+        orderby: str | t.Iterable[str] | MissingType = MISSING,
+        marker: str | MissingType = MISSING,
         query_params: dict[str, t.Any] | None = None,
     ) -> IterableFlowsResponse:
         """
         List deployed flows
 
-        :param filter_role: A role name specifying the minimum permissions required for
-            a flow to be included in the response.
+        :param filter_roles: A list of role names specifying the roles the user must
+            have for a flow to be included in the response.
         :param filter_fulltext: A string to use in a full-text search to filter results
         :param orderby: A criterion for ordering flows in the listing
         :param marker: A marker for pagination
         :param query_params: Any additional parameters to be passed through
             as query params.
 
-        **Role Values**
+        **Role Filters**
 
-        The valid values for ``role`` are, in order of precedence for ``filter_role``:
+        ``filter_roles`` accepts a list of roles which are used to filter the results to
+        flows where the caller has any of the specified roles.
 
-          - ``flow_viewer``
-          - ``flow_starter``
-          - ``flow_administrator``
-          - ``flow_owner``
+        The valid role values are:
 
-        For example, if ``flow_starter`` is specified then flows for which the user has
-        the ``flow_starter``, ``flow_administrator`` or ``flow_owner`` roles will be
-        returned.
+        - ``flow_viewer``
+        - ``flow_starter``
+        - ``flow_administrator``
+        - ``flow_owner``
+        - ``run_monitor``
+        - ``run_manager``
 
         **OrderBy Values**
 
@@ -263,7 +299,7 @@ class FlowsClient(client.BaseClient):
 
                     flows = FlowsClient(...)
                     my_frobulate_flows = flows.list_flows(
-                        filter_role="flow_owner",
+                        filter_roles="flow_owner",
                         filter_fulltext="frobulate",
                         orderby=("title ASC", "updated_at DESC"),
                     )
@@ -293,42 +329,36 @@ class FlowsClient(client.BaseClient):
                     :service: flows
                     :ref: Flows/paths/~1flows/get
         """
-
-        if query_params is None:
-            query_params = {}
-        if filter_role is not None:
-            query_params["filter_role"] = filter_role
-        if filter_fulltext is not None:
-            query_params["filter_fulltext"] = filter_fulltext
-        if orderby is not None:
-            if isinstance(orderby, str):
-                query_params["orderby"] = orderby
-            else:
-                # copy any input sequence to force the type to `list` which is known to
-                # behave well
-                # this also ensures that we will consume non-sequence iterables
-                # (e.g. generator expressions) in a well-defined way
-                query_params["orderby"] = list(orderby)
-        if marker is not None:
-            query_params["marker"] = marker
-
+        query_params = {
+            "filter_roles": commajoin(filter_roles),
+            "filter_fulltext": filter_fulltext,
+            # if `orderby` is an iterable (e.g., generator expression), it gets
+            # converted to a list in this step
+            "orderby": (
+                orderby if isinstance(orderby, (str, MissingType)) else list(orderby)
+            ),
+            "marker": marker,
+            **(query_params or {}),
+        }
         return IterableFlowsResponse(self.get("/flows", query_params=query_params))
 
     def update_flow(
         self,
-        flow_id: UUIDLike,
+        flow_id: uuid.UUID | str,
         *,
-        title: str | None = None,
-        definition: dict[str, t.Any] | None = None,
-        input_schema: dict[str, t.Any] | None = None,
-        subtitle: str | None = None,
-        description: str | None = None,
-        flow_owner: str | None = None,
-        flow_viewers: list[str] | None = None,
-        flow_starters: list[str] | None = None,
-        flow_administrators: list[str] | None = None,
-        keywords: list[str] | None = None,
-        subscription_id: UUIDLike | t.Literal["DEFAULT"] | MissingType = MISSING,
+        title: str | MissingType = MISSING,
+        definition: dict[str, t.Any] | MissingType = MISSING,
+        input_schema: dict[str, t.Any] | MissingType = MISSING,
+        subtitle: str | MissingType = MISSING,
+        description: str | MissingType = MISSING,
+        flow_owner: str | MissingType = MISSING,
+        flow_viewers: list[str] | MissingType = MISSING,
+        flow_starters: list[str] | MissingType = MISSING,
+        flow_administrators: list[str] | MissingType = MISSING,
+        run_managers: list[str] | MissingType = MISSING,
+        run_monitors: list[str] | MissingType = MISSING,
+        keywords: list[str] | MissingType = MISSING,
+        subscription_id: uuid.UUID | str | t.Literal["DEFAULT"] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
         """
@@ -396,6 +426,30 @@ class FlowsClient(client.BaseClient):
                         "urn:globus:groups:id:c1dcd951-3f35-4ea3-9f28-a7cdeaf8b68f"
                     ]
 
+        :param run_managers: A set of Principal URN values indicating entities who can
+            perform management operations on the flow's *runs*.
+
+            .. dropdown:: Example Values
+
+                .. code-block:: json
+
+                    [
+                        "urn:globus:auth:identity:b44bddda-d274-11e5-978a-9f15789a8150",
+                        "urn:globus:groups:id:c1dcd951-3f35-4ea3-9f28-a7cdeaf8b68f"
+                    ]
+
+        :param run_monitors: A set of Principal URN values indicating entities who can
+            monitor the flow's *runs*.
+
+            .. dropdown:: Example Values
+
+                .. code-block:: json
+
+                    [
+                        "urn:globus:auth:identity:b44bddda-d274-11e5-978a-9f15789a8150",
+                        "urn:globus:groups:id:c1dcd951-3f35-4ea3-9f28-a7cdeaf8b68f"
+                    ]
+
         :param keywords: A set of terms used to categorize the flow used in query and
             discovery operations (0 - 1024 items)
         :param subscription_id: A subscription ID to assign to the flow.
@@ -427,29 +481,26 @@ class FlowsClient(client.BaseClient):
         """  # noqa E501
 
         data = {
-            k: v
-            for k, v in {
-                "title": title,
-                "definition": definition,
-                "input_schema": input_schema,
-                "subtitle": subtitle,
-                "description": description,
-                "flow_owner": flow_owner,
-                "flow_viewers": flow_viewers,
-                "flow_starters": flow_starters,
-                "flow_administrators": flow_administrators,
-                "keywords": keywords,
-                "subscription_id": subscription_id,
-            }.items()
-            if v is not None and v is not MISSING
+            "title": title,
+            "definition": definition,
+            "input_schema": input_schema,
+            "subtitle": subtitle,
+            "description": description,
+            "flow_owner": flow_owner,
+            "flow_viewers": flow_viewers,
+            "flow_starters": flow_starters,
+            "flow_administrators": flow_administrators,
+            "run_managers": run_managers,
+            "run_monitors": run_monitors,
+            "keywords": keywords,
+            "subscription_id": subscription_id,
+            **(additional_fields or {}),
         }
-        data.update(additional_fields or {})
-
         return self.put(f"/flows/{flow_id}", data=data)
 
     def delete_flow(
         self,
-        flow_id: UUIDLike,
+        flow_id: uuid.UUID | str,
         *,
         query_params: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
@@ -467,10 +518,6 @@ class FlowsClient(client.BaseClient):
                     :service: flows
                     :ref: Flows/paths/~1flows~1{flow_id}/delete
         """
-
-        if query_params is None:
-            query_params = {}
-
         return self.delete(f"/flows/{flow_id}", query_params=query_params)
 
     def validate_flow(
@@ -522,24 +569,41 @@ class FlowsClient(client.BaseClient):
                     :ref: Flows/paths/~1flows~1validate/post
         """  # noqa E501
 
-        data = {"definition": definition, "input_schema": input_schema}
+        data = {
+            "definition": definition,
+            "input_schema": input_schema,
+        }
         return self.post("/flows/validate", data=data)
 
     @paging.has_paginator(paging.MarkerPaginator, items_key="runs")
     def list_runs(
         self,
         *,
-        filter_flow_id: t.Iterable[UUIDLike] | UUIDLike | None = None,
-        marker: str | None = None,
+        filter_flow_id: (
+            t.Iterable[uuid.UUID | str] | uuid.UUID | str | MissingType
+        ) = MISSING,
+        filter_roles: str | t.Iterable[str] | MissingType = MISSING,
+        marker: str | MissingType = MISSING,
         query_params: dict[str, t.Any] | None = None,
     ) -> IterableRunsResponse:
         """
         List all runs.
 
         :param filter_flow_id: One or more flow IDs used to filter the results
+        :param filter_roles: A list of role names used to filter the results
         :param marker: A pagination marker, used to get the next page of results.
         :param query_params: Any additional parameters to be passed through
 
+        **Filter Roles Values**
+
+        The valid values for ``role`` are:
+
+          - ``run_owner``
+          - ``run_manager``
+          - ``run_monitor``
+          - ``flow_run_manager``
+          - ``flow_run_monitor``
+
         .. tab-set::
 
             .. tab-item:: Example Usage
@@ -560,24 +624,22 @@ class FlowsClient(client.BaseClient):
                     :service: flows
                     :ref: Runs/paths/~1runs/get
         """
-        if query_params is None:
-            query_params = {}
-        if filter_flow_id is not None:
-            query_params["filter_flow_id"] = ",".join(
-                utils.safe_strseq_iter(filter_flow_id)
-            )
-        if marker is not None:
-            query_params["marker"] = marker
+        query_params = {
+            "filter_flow_id": commajoin(filter_flow_id),
+            "filter_roles": commajoin(filter_roles),
+            "marker": marker,
+            **(query_params or {}),
+        }
         return IterableRunsResponse(self.get("/runs", query_params=query_params))
 
     @paging.has_paginator(paging.MarkerPaginator, items_key="entries")
     def get_run_logs(
         self,
-        run_id: UUIDLike,
+        run_id: uuid.UUID | str,
         *,
-        limit: int | None = None,
-        reverse_order: bool | None = None,
-        marker: str | None = None,
+        limit: int | MissingType = MISSING,
+        reverse_order: bool | MissingType = MISSING,
+        marker: str | MissingType = MISSING,
         query_params: dict[str, t.Any] | None = None,
     ) -> IterableRunLogsResponse:
         """
@@ -616,17 +678,15 @@ class FlowsClient(client.BaseClient):
             "marker": marker,
             **(query_params or {}),
         }
-        # Filter out request keys with None values to allow server defaults
-        query_params = {k: v for k, v in query_params.items() if v is not None}
         return IterableRunLogsResponse(
             self.get(f"/runs/{run_id}/log", query_params=query_params)
         )
 
     def get_run(
         self,
-        run_id: UUIDLike,
+        run_id: uuid.UUID | str,
         *,
-        include_flow_description: bool | None = None,
+        include_flow_description: bool | MissingType = MISSING,
         query_params: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
         """
@@ -660,16 +720,15 @@ class FlowsClient(client.BaseClient):
                     :service: flows
                     :ref: Flows/paths/~1runs~1{run_id}/get
         """
-
-        query_params = query_params or {}
-        if include_flow_description is not None:
-            query_params["include_flow_description"] = include_flow_description
-
+        query_params = {
+            "include_flow_description": include_flow_description,
+            **(query_params or {}),
+        }
         return self.get(f"/runs/{run_id}", query_params=query_params)
 
     def get_run_definition(
         self,
-        run_id: UUIDLike,
+        run_id: uuid.UUID | str,
     ) -> GlobusHTTPResponse:
         """
         Get the flow definition and input schema at the time the run was started.
@@ -700,7 +759,7 @@ class FlowsClient(client.BaseClient):
 
         return self.get(f"/runs/{run_id}/definition")
 
-    def cancel_run(self, run_id: UUIDLike) -> GlobusHTTPResponse:
+    def cancel_run(self, run_id: uuid.UUID | str) -> GlobusHTTPResponse:
         """
         Cancel a run.
 
@@ -733,12 +792,12 @@ class FlowsClient(client.BaseClient):
 
     def update_run(
         self,
-        run_id: UUIDLike,
+        run_id: uuid.UUID | str,
         *,
-        label: str | None = None,
-        tags: list[str] | None = None,
-        run_monitors: list[str] | None = None,
-        run_managers: list[str] | None = None,
+        label: str | MissingType = MISSING,
+        tags: list[str] | MissingType = MISSING,
+        run_monitors: list[str] | MissingType = MISSING,
+        run_managers: list[str] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
         """
@@ -783,20 +842,15 @@ class FlowsClient(client.BaseClient):
         """
 
         data = {
-            k: v
-            for k, v in {
-                "tags": tags,
-                "label": label,
-                "run_monitors": run_monitors,
-                "run_managers": run_managers,
-            }.items()
-            if v is not None
+            "tags": tags,
+            "label": label,
+            "run_monitors": run_monitors,
+            "run_managers": run_managers,
+            **(additional_fields or {}),
         }
-        data.update(additional_fields or {})
-
         return self.put(f"/runs/{run_id}", data=data)
 
-    def delete_run(self, run_id: UUIDLike) -> GlobusHTTPResponse:
+    def delete_run(self, run_id: uuid.UUID | str) -> GlobusHTTPResponse:
         """
         Delete a run.
 
@@ -844,42 +898,107 @@ class SpecificFlowClient(client.BaseClient):
 
     error_class = FlowsAPIError
     service_name = "flows"
-    scopes: ScopeBuilder = SpecificFlowScopeBuilder._CLASS_STUB
+    scopes: SpecificFlowScopes = SpecificFlowScopes._build_class_stub()
 
     def __init__(
         self,
-        flow_id: UUIDLike,
+        flow_id: uuid.UUID | str,
         *,
         environment: str | None = None,
         app: GlobusApp | None = None,
         app_scopes: list[Scope] | None = None,
         authorizer: GlobusAuthorizer | None = None,
         app_name: str | None = None,
-        transport_params: dict[str, t.Any] | None = None,
+        transport: RequestsTransport | None = None,
+        retry_config: RetryConfig | None = None,
     ) -> None:
         self._flow_id = flow_id
-        self.scopes = SpecificFlowScopeBuilder(flow_id)
+        self.scopes = SpecificFlowScopes(flow_id)
         super().__init__(
             app=app,
             app_scopes=app_scopes,
             environment=environment,
             authorizer=authorizer,
             app_name=app_name,
-            transport_params=transport_params,
+            transport=transport,
+            retry_config=retry_config,
         )
 
     @property
     def default_scope_requirements(self) -> list[Scope]:
-        return [Scope(self.scopes.user)]
+        return [self.scopes.user]
+
+    def add_app_transfer_data_access_scope(
+        self, collection_ids: uuid.UUID | str | t.Iterable[uuid.UUID | str]
+    ) -> Self:
+        """
+        Add a dependent ``data_access`` scope for one or more given ``collection_ids``
+        to this client's ``GlobusApp``, under the Transfer ``all`` scope.
+        Useful for preventing ``ConsentRequired`` errors when starting or resuming runs
+        of flows that use Globus Connect Server mapped collection(s).
+
+        .. warning::
+
+            This method must only be used on ``collection_ids`` for non-High-Assurance
+            GCS Mapped Collections.
+
+            Use on other collection types, e.g., on GCP Mapped Collections or any form
+            of Guest Collection, will result in "Unknown Scope" errors during the login
+            flow.
+
+        Returns ``self`` for chaining.
+
+        Raises ``GlobusSDKUsageError`` if this client was not initialized with an app.
+
+        :param collection_ids: a collection ID or an iterable of IDs.
+
+        .. tab-set::
+
+            .. tab-item:: Example Usage
+
+                .. code-block:: python
+
+                    flow_id = ...
+                    COLLECTION_ID = ...
+                    app = UserApp("myapp", client_id=NATIVE_APP_CLIENT_ID)
+                    client = SpecificFlowClient(FLOW_ID, app=app).add_app_transfer_data_access_scope(
+                        COLLECTION_ID
+                    )
+
+                    client.run_flow({"collection": COLLECTION_ID})
+        """  # noqa: E501
+        if isinstance(collection_ids, (str, uuid.UUID)):
+            guards.validators.uuidlike("collection_ids", collection_ids)
+            # wrap the collection_ids input in a list for consistent iteration below
+            collection_ids_ = [collection_ids]
+        else:
+            # copy to a list so that ephemeral iterables can be iterated multiple times
+            collection_ids_ = list(collection_ids)
+            for i, c in enumerate(collection_ids_):
+                guards.validators.uuidlike(f"collection_ids[{i}]", c)
+
+        transfer_scope = TransferScopes.all.with_optional(True)
+        for coll_id in collection_ids_:
+            data_access_scope = GCSCollectionScopes(
+                str(coll_id)
+            ).data_access.with_optional(True)
+            transfer_scope = transfer_scope.with_dependency(data_access_scope)
+
+        specific_flow_scope = self.scopes.user.with_dependency(transfer_scope)
+        self.add_app_scope(specific_flow_scope)
+        return self
 
     def run_flow(
         self,
         body: dict[str, t.Any],
         *,
-        label: str | None = None,
-        tags: list[str] | None = None,
-        run_monitors: list[str] | None = None,
-        run_managers: list[str] | None = None,
+        label: str | MissingType = MISSING,
+        tags: list[str] | MissingType = MISSING,
+        activity_notification_policy: (
+            dict[str, t.Any] | RunActivityNotificationPolicy | MissingType
+        ) = MISSING,
+        run_monitors: list[str] | MissingType = MISSING,
+        run_managers: list[str] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> GlobusHTTPResponse:
         """
@@ -889,6 +1008,9 @@ class SpecificFlowClient(client.BaseClient):
         :param tags: A collection of searchable tags associated with the run. Tags are
             normalized by stripping leading and trailing whitespace, and replacing all
             whitespace with a single space.
+        :param activity_notification_policy: A policy document which declares when the
+            run will send notification emails. By default, notifications are only sent
+            when a run status changes to ``"INACTIVE"``.
         :param run_monitors: A list of authenticated entities (identified by URN)
             authorized to view this run in addition to the run owner
         :param run_managers: A list of authenticated entities (identified by URN)
@@ -905,21 +1027,17 @@ class SpecificFlowClient(client.BaseClient):
                     :ref: ~1flows~1{flow_id}~1run/post
         """
         data = {
-            k: v
-            for k, v in {
-                "body": body,
-                "tags": tags,
-                "label": label,
-                "run_monitors": run_monitors,
-                "run_managers": run_managers,
-            }.items()
-            if v is not None
+            "body": body,
+            "tags": tags,
+            "label": label,
+            "activity_notification_policy": activity_notification_policy,
+            "run_monitors": run_monitors,
+            "run_managers": run_managers,
+            **(additional_fields or {}),
         }
-        data.update(additional_fields or {})
-
         return self.post(f"/flows/{self._flow_id}/run", data=data)
 
-    def resume_run(self, run_id: UUIDLike) -> GlobusHTTPResponse:
+    def resume_run(self, run_id: uuid.UUID | str) -> GlobusHTTPResponse:
         """
         :param run_id: The ID of the run to resume
 
@@ -946,3 +1064,60 @@ class SpecificFlowClient(client.BaseClient):
                     :ref: Runs/paths/~1flows~1{flow_id}~1runs~1{run_id}~1resume/post
         """
         return self.post(f"/runs/{run_id}/resume")
+
+    def validate_run(
+        self,
+        body: dict[str, t.Any],
+        *,
+        label: str | MissingType = MISSING,
+        tags: list[str] | MissingType = MISSING,
+        run_monitors: list[str] | MissingType = MISSING,
+        run_managers: list[str] | MissingType = MISSING,
+        activity_notification_policy: (
+            dict[str, t.Any] | RunActivityNotificationPolicy | MissingType
+        ) = MISSING,
+        additional_fields: dict[str, t.Any] | None = None,
+    ) -> GlobusHTTPResponse:
+        """
+        :param body: The parameters to validate against the flow's input schema.
+        :param label: A short human-readable title.
+        :param tags: A collection of searchable tags associated with the run.
+            Tags are normalized by stripping leading and trailing whitespace,
+            and replacing all whitespace with a single space.
+        :param run_monitors: A list of Globus Auth principals (identified by URN)
+            authorized to monitor this run (in addition to the run owner).
+        :param run_managers: A list of Globus Auth principals (identified by URN)
+            authorized to manage this run (in addition to the run owner).
+        :param activity_notification_policy:
+            A policy document which declares when the Flows service will send
+            notification emails regarding the run's activity.
+        :param additional_fields: Additional key/value pairs sent to the run API.
+            This parameter can be used to bypass SDK parameter validation.
+
+        .. tab-set::
+
+            .. tab-item:: Example Usage
+
+                .. code-block:: python
+
+                    from globus_sdk import SpecificFlowClient
+
+                    ...
+                    flow = SpecificFlowClient(flow_id, ...)
+                    flow.validate_run(body={"param": "value"})
+            .. tab-item:: Example Response Data
+
+                .. expandtestfixture:: flows.validate_run
+        """
+
+        data = {
+            "body": body,
+            "tags": tags,
+            "label": label,
+            "run_monitors": run_monitors,
+            "run_managers": run_managers,
+            "activity_notification_policy": activity_notification_policy,
+        }
+        data.update(additional_fields or {})
+
+        return self.post(f"/flows/{self._flow_id}/validate_run", data=data)
