@@ -2,9 +2,11 @@ from __future__ import annotations
 
 import abc
 import typing as t
+import uuid
 
-from globus_sdk import utils
-from globus_sdk._types import UUIDLike
+from globus_sdk._internal.remarshal import strseq_listify
+from globus_sdk._missing import MISSING, MissingType
+from globus_sdk._payload import AbstractGlobusPayload
 
 from ._common import (
     DatatypeCallback,
@@ -35,6 +37,7 @@ from ._common import (
 # - strings, sorted alphabetically
 # - string lists, sorted alphabetically
 # - bools, sorted alphabetically
+# - ints, sorted alphabetically
 # - dicts and other types, sorted alphabetically
 #
 # This makes it possible to do side-by-side comparison of common arguments, to ensure
@@ -56,7 +59,9 @@ def _user_message_length_callback(
     return None
 
 
-class CollectionDocument(utils.PayloadWrapper, abc.ABC):
+# Declare a metaclass of ABCMeta even though inheriting from `Payload` renders it
+# inert. This will let type checkers understand that this class is abstract.
+class CollectionDocument(AbstractGlobusPayload):
     """
     This is the base class for :class:`~.MappedCollectionDocument` and
     :class:`~.GuestCollectionDocument`.
@@ -85,6 +90,9 @@ class CollectionDocument(utils.PayloadWrapper, abc.ABC):
         collection
     :param info_link: Link for more info about the collection
     :param organization: The organization which maintains the collection
+    :param restrict_transfers_to_high_assurance: Require that transfers of the
+        given type involve only collections that are high assurance.
+        Valid values: "inbound", "outbound", "all", None
     :param user_message: A message to display to users when interacting with this
         collection
     :param user_message_link: A link to additional messaging for users when interacting
@@ -101,11 +109,27 @@ class CollectionDocument(utils.PayloadWrapper, abc.ABC):
         collection
     :param public: If True, the collection will be visible to other Globus users
 
+    :param acl_expiration_mins: Length of time that guest collection permissions are
+        valid. Only settable on HA guest collections and HA mapped collections and
+        used by guest collections attached to it. When set on both the mapped and guest
+        collections, the lesser value is in effect.
+
+    :param associated_flow_policy: Policy describing Globus flows to run when the
+        collection is accessed. See
+        https://docs.globus.org/api/transfer/endpoints_and_collections/#associated_flow_policy
+        for expected shape.
+
     :param additional_fields: Additional data for inclusion in the collection document
     """
 
     DATATYPE_BASE: str = "collection"
     DATATYPE_VERSION_IMPLICATIONS: dict[str, tuple[int, int, int]] = {
+        "associated_flow_policy": (1, 15, 0),
+        "activity_notification_policy": (1, 14, 0),
+        "auto_delete_timeout": (1, 13, 0),
+        "skip_auto_delete": (1, 13, 0),
+        "restrict_transfers_to_high_assurance": (1, 12, 0),
+        "acl_expiration_mins": (1, 10, 0),
         "delete_protected": (1, 8, 0),
         "guest_auth_policy_id": (1, 6, 0),
         "disable_anonymous_writes": (1, 5, 0),
@@ -124,59 +148,66 @@ class CollectionDocument(utils.PayloadWrapper, abc.ABC):
         self,
         *,
         # data_type
-        data_type: str | None = None,
+        data_type: str | MissingType = MISSING,
         # strs
-        collection_base_path: str | None = None,
-        contact_email: str | None = None,
-        contact_info: str | None = None,
-        default_directory: str | None = None,
-        department: str | None = None,
-        description: str | None = None,
-        display_name: str | None = None,
-        identity_id: UUIDLike | None = None,
-        info_link: str | None = None,
-        organization: str | None = None,
-        user_message: str | None = None,
-        user_message_link: str | None = None,
+        collection_base_path: str | MissingType = MISSING,
+        contact_email: str | None | MissingType = MISSING,
+        contact_info: str | None | MissingType = MISSING,
+        default_directory: str | MissingType = MISSING,
+        department: str | None | MissingType = MISSING,
+        description: str | None | MissingType = MISSING,
+        display_name: str | MissingType = MISSING,
+        identity_id: uuid.UUID | str | MissingType = MISSING,
+        info_link: str | None | MissingType = MISSING,
+        organization: str | MissingType = MISSING,
+        restrict_transfers_to_high_assurance: (
+            t.Literal["inbound", "outbound", "all"] | MissingType
+        ) = MISSING,
+        user_message: str | None | MissingType = MISSING,
+        user_message_link: str | None | MissingType = MISSING,
         # str lists
-        keywords: t.Iterable[str] | None = None,
+        keywords: t.Iterable[str] | MissingType = MISSING,
         # bools
-        disable_verify: bool | None = None,
-        enable_https: bool | None = None,
-        force_encryption: bool | None = None,
-        force_verify: bool | None = None,
-        public: bool | None = None,
+        disable_verify: bool | MissingType = MISSING,
+        enable_https: bool | MissingType = MISSING,
+        force_encryption: bool | MissingType = MISSING,
+        force_verify: bool | MissingType = MISSING,
+        public: bool | MissingType = MISSING,
+        # ints
+        acl_expiration_mins: int | MissingType = MISSING,
+        # dicts
+        associated_flow_policy: dict[str, t.Any] | MissingType = MISSING,
         # additional fields
-        additional_fields: dict[str, t.Any] | None = None,
+        additional_fields: dict[str, t.Any] | MissingType = MISSING,
     ) -> None:
         super().__init__()
         self["collection_type"] = self.collection_type
-        self._set_optstrs(
-            DATA_TYPE=data_type,
-            collection_base_path=collection_base_path,
-            contact_email=contact_email,
-            contact_info=contact_info,
-            default_directory=default_directory,
-            department=department,
-            description=description,
-            display_name=display_name,
-            identity_id=identity_id,
-            info_link=info_link,
-            organization=organization,
-            user_message=user_message,
-            user_message_link=user_message_link,
+        self["DATA_TYPE"] = data_type
+        self["collection_base_path"] = collection_base_path
+        self["contact_email"] = contact_email
+        self["contact_info"] = contact_info
+        self["default_directory"] = default_directory
+        self["department"] = department
+        self["description"] = description
+        self["display_name"] = display_name
+        self["identity_id"] = identity_id
+        self["info_link"] = info_link
+        self["organization"] = organization
+        self["restrict_transfers_to_high_assurance"] = (
+            restrict_transfers_to_high_assurance
         )
-        self._set_optstrlists(
-            keywords=keywords,
-        )
-        self._set_optbools(
-            disable_verify=disable_verify,
-            enable_https=enable_https,
-            force_encryption=force_encryption,
-            force_verify=force_verify,
-            public=public,
-        )
-        if additional_fields is not None:
+        self["user_message"] = user_message
+        self["user_message_link"] = user_message_link
+        self["keywords"] = strseq_listify(keywords)
+        self["disable_verify"] = disable_verify
+        self["enable_https"] = enable_https
+        self["force_encryption"] = force_encryption
+        self["force_verify"] = force_verify
+        self["public"] = public
+        self["acl_expiration_mins"] = acl_expiration_mins
+        self["associated_flow_policy"] = associated_flow_policy
+
+        if additional_fields is not MISSING:
             self.update(additional_fields)
 
     @property
@@ -221,6 +252,9 @@ class MappedCollectionDocument(CollectionDocument):
         attached to this Mapped Collection. This option is only usable on non
         high-assurance collections
 
+    :param auto_delete_timeout: Delete child guest collections that have not been
+        accessed within the specified timeout period in days.
+
     :param policies: Connector-specific collection policies
     :param sharing_restrict_paths: A PathRestrictions document
     """
@@ -233,48 +267,56 @@ class MappedCollectionDocument(CollectionDocument):
         self,
         *,
         # data type
-        data_type: str | None = None,
+        data_type: str | MissingType = MISSING,
         # > common args start <
         # strs
-        collection_base_path: str | None = None,
-        contact_email: str | None = None,
-        contact_info: str | None = None,
-        default_directory: str | None = None,
-        department: str | None = None,
-        description: str | None = None,
-        display_name: str | None = None,
-        identity_id: UUIDLike | None = None,
-        info_link: str | None = None,
-        organization: str | None = None,
-        user_message: str | None = None,
-        user_message_link: str | None = None,
+        collection_base_path: str | MissingType = MISSING,
+        contact_email: str | None | MissingType = MISSING,
+        contact_info: str | None | MissingType = MISSING,
+        default_directory: str | MissingType = MISSING,
+        department: str | None | MissingType = MISSING,
+        description: str | None | MissingType = MISSING,
+        display_name: str | MissingType = MISSING,
+        identity_id: uuid.UUID | str | MissingType = MISSING,
+        info_link: str | None | MissingType = MISSING,
+        organization: str | MissingType = MISSING,
+        restrict_transfers_to_high_assurance: (
+            t.Literal["inbound", "outbound", "all"] | MissingType
+        ) = MISSING,
+        user_message: str | None | MissingType = MISSING,
+        user_message_link: str | None | MissingType = MISSING,
         # str lists
-        keywords: t.Iterable[str] | None = None,
+        keywords: t.Iterable[str] | MissingType = MISSING,
         # bools
-        disable_verify: bool | None = None,
-        enable_https: bool | None = None,
-        force_encryption: bool | None = None,
-        force_verify: bool | None = None,
-        public: bool | None = None,
+        disable_verify: bool | MissingType = MISSING,
+        enable_https: bool | MissingType = MISSING,
+        force_encryption: bool | MissingType = MISSING,
+        force_verify: bool | MissingType = MISSING,
+        public: bool | MissingType = MISSING,
+        # ints
+        acl_expiration_mins: int | MissingType = MISSING,
         # > common args end <
         # > specific args start <
         # strs
-        domain_name: str | None = None,
-        guest_auth_policy_id: UUIDLike | None = None,
-        storage_gateway_id: UUIDLike | None = None,
+        domain_name: str | MissingType = MISSING,
+        guest_auth_policy_id: uuid.UUID | str | None | MissingType = MISSING,
+        storage_gateway_id: uuid.UUID | str | MissingType = MISSING,
         # str lists
-        sharing_users_allow: t.Iterable[str] | None = None,
-        sharing_users_deny: t.Iterable[str] | None = None,
-        sharing_restrict_paths: dict[str, t.Any] | None = None,
+        sharing_users_allow: t.Iterable[str] | None | MissingType = MISSING,
+        sharing_users_deny: t.Iterable[str] | None | MissingType = MISSING,
+        sharing_restrict_paths: dict[str, t.Any] | None | MissingType = MISSING,
         # bools
-        delete_protected: bool | None = None,
-        allow_guest_collections: bool | None = None,
-        disable_anonymous_writes: bool | None = None,
+        delete_protected: bool | MissingType = MISSING,
+        allow_guest_collections: bool | MissingType = MISSING,
+        disable_anonymous_writes: bool | MissingType = MISSING,
+        # ints
+        auto_delete_timeout: int | MissingType = MISSING,
         # dicts
-        policies: CollectionPolicies | dict[str, t.Any] | None = None,
+        associated_flow_policy: dict[str, t.Any] | MissingType = MISSING,
+        policies: CollectionPolicies | dict[str, t.Any] | MissingType = MISSING,
         # > specific args end <
         # additional fields
-        additional_fields: dict[str, t.Any] | None = None,
+        additional_fields: dict[str, t.Any] | MissingType = MISSING,
     ) -> None:
         super().__init__(
             # data type
@@ -290,6 +332,7 @@ class MappedCollectionDocument(CollectionDocument):
             identity_id=identity_id,
             info_link=info_link,
             organization=organization,
+            restrict_transfers_to_high_assurance=restrict_transfers_to_high_assurance,
             user_message=user_message,
             user_message_link=user_message_link,
             # bools
@@ -298,27 +341,31 @@ class MappedCollectionDocument(CollectionDocument):
             force_encryption=force_encryption,
             force_verify=force_verify,
             public=public,
+            # ints
+            acl_expiration_mins=acl_expiration_mins,
             # str lists
             keywords=keywords,
+            # str dicts
+            associated_flow_policy=associated_flow_policy,
             # additional fields
             additional_fields=additional_fields,
         )
-        self._set_optstrs(
-            domain_name=domain_name,
-            guest_auth_policy_id=guest_auth_policy_id,
-            storage_gateway_id=storage_gateway_id,
+        self["domain_name"] = domain_name
+        self["restrict_transfers_to_high_assurance"] = (
+            restrict_transfers_to_high_assurance
         )
-        self._set_optstrlists(
-            sharing_users_allow=sharing_users_allow,
-            sharing_users_deny=sharing_users_deny,
-        )
-        self._set_optbools(
-            delete_protected=delete_protected,
-            allow_guest_collections=allow_guest_collections,
-            disable_anonymous_writes=disable_anonymous_writes,
-        )
-        self._set_value("sharing_restrict_paths", sharing_restrict_paths)
-        self._set_value("policies", policies)
+        self["guest_auth_policy_id"] = guest_auth_policy_id
+        self["storage_gateway_id"] = storage_gateway_id
+
+        self["sharing_users_allow"] = strseq_listify(sharing_users_allow)
+        self["sharing_users_deny"] = strseq_listify(sharing_users_deny)
+
+        self["delete_protected"] = delete_protected
+        self["allow_guest_collections"] = allow_guest_collections
+        self["disable_anonymous_writes"] = disable_anonymous_writes
+        self["auto_delete_timeout"] = auto_delete_timeout
+        self["sharing_restrict_paths"] = sharing_restrict_paths
+        self["policies"] = policies
         ensure_datatype(self)
 
 
@@ -343,6 +390,13 @@ class GuestCollectionDocument(CollectionDocument):
     :param user_credential_id: The ID of the User Credential which is used to access
         data on this collection. This credential must be owned by the collection’s
         ``identity_id``.
+
+    :param skip_auto_delete: Indicates whether the collection is exempt from its
+        parent mapped collection's automatic deletion policy.
+
+    :param activity_notification_policy: Specification for when a notification email
+        should be sent to a guest collection ``administrator``, ``activity_manager``,
+        and ``activity_monitor`` roles when a transfer task reaches completion.
     """
 
     @property
@@ -353,36 +407,45 @@ class GuestCollectionDocument(CollectionDocument):
         self,
         *,
         # data type
-        data_type: str | None = None,
+        data_type: str | MissingType = MISSING,
         # > common args start <
         # strs
-        collection_base_path: str | None = None,
-        contact_email: str | None = None,
-        contact_info: str | None = None,
-        default_directory: str | None = None,
-        department: str | None = None,
-        description: str | None = None,
-        display_name: str | None = None,
-        identity_id: UUIDLike | None = None,
-        info_link: str | None = None,
-        organization: str | None = None,
-        user_message: str | None = None,
-        user_message_link: str | None = None,
+        collection_base_path: str | MissingType = MISSING,
+        contact_email: str | None | MissingType = MISSING,
+        contact_info: str | None | MissingType = MISSING,
+        default_directory: str | MissingType = MISSING,
+        department: str | None | MissingType = MISSING,
+        description: str | None | MissingType = MISSING,
+        display_name: str | MissingType = MISSING,
+        identity_id: uuid.UUID | str | MissingType = MISSING,
+        info_link: str | None | MissingType = MISSING,
+        organization: str | MissingType = MISSING,
+        restrict_transfers_to_high_assurance: (
+            t.Literal["inbound", "outbound", "all"] | MissingType
+        ) = MISSING,
+        user_message: str | None | MissingType = MISSING,
+        user_message_link: str | None | MissingType = MISSING,
         # str lists
-        keywords: t.Iterable[str] | None = None,
+        keywords: t.Iterable[str] | MissingType = MISSING,
         # bools
-        disable_verify: bool | None = None,
-        enable_https: bool | None = None,
-        force_encryption: bool | None = None,
-        force_verify: bool | None = None,
-        public: bool | None = None,
+        disable_verify: bool | MissingType = MISSING,
+        enable_https: bool | MissingType = MISSING,
+        force_encryption: bool | MissingType = MISSING,
+        force_verify: bool | MissingType = MISSING,
+        public: bool | MissingType = MISSING,
+        # ints
+        acl_expiration_mins: int | MissingType = MISSING,
+        # dicts
+        associated_flow_policy: dict[str, t.Any] | MissingType = MISSING,
         # > common args end <
         # > specific args start <
-        mapped_collection_id: UUIDLike | None = None,
-        user_credential_id: UUIDLike | None = None,
+        mapped_collection_id: uuid.UUID | str | MissingType = MISSING,
+        user_credential_id: uuid.UUID | str | MissingType = MISSING,
+        skip_auto_delete: bool | MissingType = MISSING,
+        activity_notification_policy: dict[str, list[str]] | MissingType = MISSING,
         # > specific args end <
         # additional fields
-        additional_fields: dict[str, t.Any] | None = None,
+        additional_fields: dict[str, t.Any] | MissingType = MISSING,
     ) -> None:
         super().__init__(
             # data type
@@ -398,6 +461,7 @@ class GuestCollectionDocument(CollectionDocument):
             identity_id=identity_id,
             info_link=info_link,
             organization=organization,
+            restrict_transfers_to_high_assurance=restrict_transfers_to_high_assurance,
             user_message=user_message,
             user_message_link=user_message_link,
             # bools
@@ -406,19 +470,24 @@ class GuestCollectionDocument(CollectionDocument):
             force_encryption=force_encryption,
             force_verify=force_verify,
             public=public,
+            # ints
+            acl_expiration_mins=acl_expiration_mins,
             # str lists
             keywords=keywords,
+            # dicts
+            associated_flow_policy=associated_flow_policy,
             # additional fields
             additional_fields=additional_fields,
         )
-        self._set_optstrs(
-            mapped_collection_id=mapped_collection_id,
-            user_credential_id=user_credential_id,
-        )
+
+        self["mapped_collection_id"] = mapped_collection_id
+        self["user_credential_id"] = user_credential_id
+        self["skip_auto_delete"] = skip_auto_delete
+        self["activity_notification_policy"] = activity_notification_policy
         ensure_datatype(self)
 
 
-class CollectionPolicies(utils.PayloadWrapper, abc.ABC):
+class CollectionPolicies(AbstractGlobusPayload):
     """
     This is the abstract base type for Collection Policies documents to use as the
     ``policies`` parameter when creating a MappedCollectionDocument.
@@ -443,17 +512,17 @@ class POSIXCollectionPolicies(CollectionPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "posix_collection_policies#1.0.0",
-        sharing_groups_allow: None | str | t.Iterable[str] = None,
-        sharing_groups_deny: None | str | t.Iterable[str] = None,
-        additional_fields: dict[str, t.Any] | None = None,
+        sharing_groups_allow: str | t.Iterable[str] | None | MissingType = MISSING,
+        sharing_groups_deny: str | t.Iterable[str] | None | MissingType = MISSING,
+        additional_fields: dict[str, t.Any] | MissingType = MISSING,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE)
-        self._set_optstrlists(
-            sharing_groups_allow=sharing_groups_allow,
-            sharing_groups_deny=sharing_groups_deny,
-        )
-        if additional_fields is not None:
+        self["DATA_TYPE"] = DATA_TYPE
+
+        self["sharing_groups_allow"] = strseq_listify(sharing_groups_allow)
+        self["sharing_groups_deny"] = strseq_listify(sharing_groups_deny)
+
+        if additional_fields is not MISSING:
             self.update(additional_fields)
 
 
@@ -475,17 +544,16 @@ class POSIXStagingCollectionPolicies(CollectionPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "posix_staging_collection_policies#1.0.0",
-        sharing_groups_allow: None | str | t.Iterable[str] = None,
-        sharing_groups_deny: None | str | t.Iterable[str] = None,
-        additional_fields: dict[str, t.Any] | None = None,
+        sharing_groups_allow: str | t.Iterable[str] | None | MissingType = MISSING,
+        sharing_groups_deny: str | t.Iterable[str] | None | MissingType = MISSING,
+        additional_fields: dict[str, t.Any] | MissingType = MISSING,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE)
-        self._set_optstrlists(
-            sharing_groups_allow=sharing_groups_allow,
-            sharing_groups_deny=sharing_groups_deny,
-        )
-        if additional_fields is not None:
+        self["DATA_TYPE"] = DATA_TYPE
+        self["sharing_groups_allow"] = strseq_listify(sharing_groups_allow)
+        self["sharing_groups_deny"] = strseq_listify(sharing_groups_deny)
+
+        if additional_fields is not MISSING:
             self.update(additional_fields)
 
 
@@ -503,10 +571,11 @@ class GoogleCloudStorageCollectionPolicies(CollectionPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "google_cloud_storage_collection_policies#1.0.0",
-        project: str | None = None,
-        additional_fields: dict[str, t.Any] | None = None,
+        project: str | MissingType = MISSING,
+        additional_fields: dict[str, t.Any] | MissingType = MISSING,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE, project=project)
-        if additional_fields is not None:
+        self["DATA_TYPE"] = DATA_TYPE
+        self["project"] = project
+        if additional_fields is not MISSING:
             self.update(additional_fields)
