@@ -1,15 +1,17 @@
 from __future__ import annotations
 
-import abc
+import copy
 import typing as t
+import uuid
 
-from globus_sdk import utils
-from globus_sdk._types import UUIDLike
+from globus_sdk._internal.remarshal import list_map, listify, strseq_listify
+from globus_sdk._missing import MISSING, MissingType
+from globus_sdk._payload import AbstractGlobusPayload, GlobusPayload
 
 from ._common import DatatypeCallback, ensure_datatype
 
 
-class StorageGatewayDocument(utils.PayloadWrapper):
+class StorageGatewayDocument(GlobusPayload):
     """
     Convenience class for constructing a Storage Gateway document
     to use as the `data` parameter to ``create_storage_gateway`` or
@@ -56,42 +58,38 @@ class StorageGatewayDocument(utils.PayloadWrapper):
 
     def __init__(
         self,
-        DATA_TYPE: str | None = None,
-        display_name: str | None = None,
-        connector_id: UUIDLike | None = None,
-        root: str | None = None,
-        identity_mappings: None | t.Iterable[dict[str, t.Any]] = None,
-        policies: StorageGatewayPolicies | dict[str, t.Any] | None = None,
-        allowed_domains: t.Iterable[str] | None = None,
-        high_assurance: bool | None = None,
-        require_mfa: bool | None = None,
-        authentication_timeout_mins: int | None = None,
-        users_allow: t.Iterable[str] | None = None,
-        users_deny: t.Iterable[str] | None = None,
+        DATA_TYPE: str | MissingType = MISSING,
+        display_name: str | MissingType = MISSING,
+        connector_id: uuid.UUID | str | MissingType = MISSING,
+        root: str | MissingType = MISSING,
+        identity_mappings: t.Iterable[dict[str, t.Any]] | MissingType = MISSING,
+        policies: StorageGatewayPolicies | dict[str, t.Any] | MissingType = MISSING,
+        allowed_domains: t.Iterable[str] | MissingType = MISSING,
+        high_assurance: bool | MissingType = MISSING,
+        require_mfa: bool | MissingType = MISSING,
+        authentication_timeout_mins: int | MissingType = MISSING,
+        users_allow: t.Iterable[str] | MissingType = MISSING,
+        users_deny: t.Iterable[str] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE,
-            display_name=display_name,
-            connector_id=connector_id,
-            root=root,
-        )
-        self._set_optstrlists(
-            allowed_domains=allowed_domains,
-            users_allow=users_allow,
-            users_deny=users_deny,
-        )
-        self._set_optbools(high_assurance=high_assurance, require_mfa=require_mfa)
-        self._set_optints(authentication_timeout_mins=authentication_timeout_mins)
-        self._set_value("identity_mappings", identity_mappings, callback=list)
-        self._set_value("policies", policies)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["display_name"] = display_name
+        self["connector_id"] = connector_id
+        self["root"] = root
+        self["allowed_domains"] = strseq_listify(allowed_domains)
+        self["users_allow"] = strseq_listify(users_allow)
+        self["users_deny"] = strseq_listify(users_deny)
+        self["high_assurance"] = high_assurance
+        self["require_mfa"] = require_mfa
+        self["authentication_timeout_mins"] = authentication_timeout_mins
+        self["identity_mappings"] = listify(identity_mappings)
+        self["policies"] = policies
+        self.update(additional_fields or {})
         ensure_datatype(self)
 
 
-class StorageGatewayPolicies(utils.PayloadWrapper, abc.ABC):
+class StorageGatewayPolicies(AbstractGlobusPayload):
     """
     This is the abstract base type for Storage Policies documents to use as the
     ``policies`` parameter when creating a StorageGatewayDocument.
@@ -118,15 +116,15 @@ class POSIXStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "posix_storage_policies#1.0.0",
-        groups_allow: t.Iterable[str] | None = None,
-        groups_deny: t.Iterable[str] | None = None,
+        groups_allow: t.Iterable[str] | MissingType = MISSING,
+        groups_deny: t.Iterable[str] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE)
-        self._set_optstrlists(groups_allow=groups_allow, groups_deny=groups_deny)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["groups_allow"] = strseq_listify(groups_allow)
+        self["groups_deny"] = strseq_listify(groups_deny)
+        self.update(additional_fields or {})
 
 
 class POSIXStagingStoragePolicies(StorageGatewayPolicies):
@@ -149,22 +147,20 @@ class POSIXStagingStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "posix_staging_storage_policies#1.0.0",
-        groups_allow: t.Iterable[str] | None = None,
-        groups_deny: t.Iterable[str] | None = None,
-        stage_app: str | None = None,
-        environment: t.Iterable[dict[str, str]] | None = None,
+        groups_allow: t.Iterable[str] | MissingType = MISSING,
+        groups_deny: t.Iterable[str] | MissingType = MISSING,
+        stage_app: str | MissingType = MISSING,
+        environment: t.Iterable[dict[str, str]] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE, stage_app=stage_app)
-        self._set_optstrlists(groups_allow=groups_allow, groups_deny=groups_deny)
-        self._set_value(
-            "environment",
-            environment,
-            callback=lambda env_iter: [{**e} for e in env_iter],
-        )
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["stage_app"] = stage_app
+        self["groups_allow"] = strseq_listify(groups_allow)
+        self["groups_deny"] = strseq_listify(groups_deny)
+        # make shallow copies of all the dicts passed
+        self["environment"] = list_map(environment, copy.copy)
+        self.update(additional_fields or {})
 
 
 class BlackPearlStoragePolicies(StorageGatewayPolicies):
@@ -185,18 +181,15 @@ class BlackPearlStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "blackpearl_storage_policies#1.0.0",
-        s3_endpoint: str | None = None,
-        bp_access_id_file: str | None = None,
+        s3_endpoint: str | MissingType = MISSING,
+        bp_access_id_file: str | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE,
-            s3_endpoint=s3_endpoint,
-            bp_access_id_file=bp_access_id_file,
-        )
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["s3_endpoint"] = s3_endpoint
+        self["bp_access_id_file"] = bp_access_id_file
+        self.update(additional_fields or {})
 
 
 class BoxStoragePolicies(StorageGatewayPolicies):
@@ -216,15 +209,15 @@ class BoxStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "box_storage_policies#1.0.0",
-        enterpriseID: str | None = None,
-        boxAppSettings: dict[str, t.Any] | None = None,
+        enterpriseID: str | MissingType = MISSING,
+        boxAppSettings: dict[str, t.Any] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE, enterpriseID=enterpriseID)
-        self._set_value("boxAppSettings", boxAppSettings)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["enterpriseID"] = enterpriseID
+        self["boxAppSettings"] = boxAppSettings
+        self.update(additional_fields or {})
 
 
 class CephStoragePolicies(StorageGatewayPolicies):
@@ -247,22 +240,19 @@ class CephStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "ceph_storage_policies#1.0.0",
-        s3_endpoint: str | None = None,
-        s3_buckets: t.Iterable[str] | None = None,
-        ceph_admin_key_id: str | None = None,
-        ceph_admin_secret_key: str | None = None,
+        s3_endpoint: str | MissingType = MISSING,
+        s3_buckets: t.Iterable[str] | MissingType = MISSING,
+        ceph_admin_key_id: str | MissingType = MISSING,
+        ceph_admin_secret_key: str | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE,
-            s3_endpoint=s3_endpoint,
-            ceph_admin_key_id=ceph_admin_key_id,
-            ceph_admin_secret_key=ceph_admin_secret_key,
-        )
-        self._set_optstrlists(s3_buckets=s3_buckets)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["s3_endpoint"] = s3_endpoint
+        self["ceph_admin_key_id"] = ceph_admin_key_id
+        self["ceph_admin_secret_key"] = ceph_admin_secret_key
+        self["s3_buckets"] = strseq_listify(s3_buckets)
+        self.update(additional_fields or {})
 
 
 class GoogleDriveStoragePolicies(StorageGatewayPolicies):
@@ -283,16 +273,17 @@ class GoogleDriveStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "google_drive_storage_policies#1.0.0",
-        client_id: str | None = None,
-        secret: str | None = None,
-        user_api_rate_quota: int | None = None,
+        client_id: str | MissingType = MISSING,
+        secret: str | MissingType = MISSING,
+        user_api_rate_quota: int | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE, client_id=client_id, secret=secret)
-        self._set_optints(user_api_rate_quota=user_api_rate_quota)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["client_id"] = client_id
+        self["secret"] = secret
+        self["user_api_rate_quota"] = user_api_rate_quota
+        self.update(additional_fields or {})
 
 
 class GoogleCloudStoragePolicies(StorageGatewayPolicies):
@@ -323,19 +314,21 @@ class GoogleCloudStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "google_cloud_storage_policies#1.0.0",
-        client_id: str | None = None,
-        secret: str | None = None,
-        service_account_key: dict[str, t.Any] | None = None,
-        buckets: t.Iterable[str] | None = None,
-        projects: t.Iterable[str] | None = None,
+        client_id: str | MissingType = MISSING,
+        secret: str | MissingType = MISSING,
+        service_account_key: dict[str, t.Any] | MissingType = MISSING,
+        buckets: t.Iterable[str] | MissingType = MISSING,
+        projects: t.Iterable[str] | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE, client_id=client_id, secret=secret)
-        self._set_optstrlists(buckets=buckets, projects=projects)
-        self._set_value("service_account_key", service_account_key)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["client_id"] = client_id
+        self["secret"] = secret
+        self["buckets"] = strseq_listify(buckets)
+        self["projects"] = strseq_listify(projects)
+        self["service_account_key"] = service_account_key
+        self.update(additional_fields or {})
 
 
 class OneDriveStoragePolicies(StorageGatewayPolicies):
@@ -357,19 +350,19 @@ class OneDriveStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "onedrive_storage_policies#1.0.0",
-        client_id: str | None = None,
-        secret: str | None = None,
-        tenant: str | None = None,
-        user_api_rate_limit: int | None = None,
+        client_id: str | MissingType = MISSING,
+        secret: str | MissingType = MISSING,
+        tenant: str | MissingType = MISSING,
+        user_api_rate_limit: int | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE, client_id=client_id, secret=secret, tenant=tenant
-        )
-        self._set_optints(user_api_rate_limit=user_api_rate_limit)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["client_id"] = client_id
+        self["secret"] = secret
+        self["tenant"] = tenant
+        self["user_api_rate_limit"] = user_api_rate_limit
+        self.update(additional_fields or {})
 
 
 class AzureBlobStoragePolicies(StorageGatewayPolicies):
@@ -393,26 +386,23 @@ class AzureBlobStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "azure_blob_storage_policies#1.0.0",
-        client_id: str | None = None,
-        secret: str | None = None,
-        tenant: str | None = None,
-        account: str | None = None,
-        auth_type: str | None = None,
-        adls: bool | None = None,
+        client_id: str | MissingType = MISSING,
+        secret: str | MissingType = MISSING,
+        tenant: str | MissingType = MISSING,
+        account: str | MissingType = MISSING,
+        auth_type: str | MissingType = MISSING,
+        adls: bool | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE,
-            client_id=client_id,
-            secret=secret,
-            tenant=tenant,
-            account=account,
-            auth_type=auth_type,
-        )
-        self._set_optbools(adls=adls)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["client_id"] = client_id
+        self["secret"] = secret
+        self["tenant"] = tenant
+        self["account"] = account
+        self["auth_type"] = auth_type
+        self["adls"] = adls
+        self.update(additional_fields or {})
 
 
 class S3StoragePolicies(StorageGatewayPolicies):
@@ -435,17 +425,17 @@ class S3StoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "s3_storage_policies#1.0.0",
-        s3_endpoint: str | None = None,
-        s3_buckets: t.Iterable[str] | None = None,
-        s3_user_credential_required: bool | None = None,
+        s3_endpoint: str | MissingType = MISSING,
+        s3_buckets: t.Iterable[str] | MissingType = MISSING,
+        s3_user_credential_required: bool | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(DATA_TYPE=DATA_TYPE, s3_endpoint=s3_endpoint)
-        self._set_optbools(s3_user_credential_required=s3_user_credential_required)
-        self._set_optstrlists(s3_buckets=s3_buckets)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["s3_endpoint"] = s3_endpoint
+        self["s3_user_credential_required"] = s3_user_credential_required
+        self["s3_buckets"] = strseq_listify(s3_buckets)
+        self.update(additional_fields or {})
 
 
 class ActiveScaleStoragePolicies(S3StoragePolicies):
@@ -470,18 +460,15 @@ class IrodsStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "irods_storage_policies#1.0.0",
-        irods_environment_file: str | None = None,
-        irods_authentication_file: str | None = None,
+        irods_environment_file: str | MissingType = MISSING,
+        irods_authentication_file: str | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE,
-            irods_environment_file=irods_environment_file,
-            irods_authentication_file=irods_authentication_file,
-        )
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["irods_environment_file"] = irods_environment_file
+        self["irods_authentication_file"] = irods_authentication_file
+        self.update(additional_fields or {})
 
 
 class HPSSStoragePolicies(StorageGatewayPolicies):
@@ -501,17 +488,14 @@ class HPSSStoragePolicies(StorageGatewayPolicies):
     def __init__(
         self,
         DATA_TYPE: str = "hpss_storage_policies#1.0.0",
-        authentication_mech: str | None = None,
-        authenticator: str | None = None,
-        uda_checksum_support: bool | None = None,
+        authentication_mech: str | MissingType = MISSING,
+        authenticator: str | MissingType = MISSING,
+        uda_checksum_support: bool | MissingType = MISSING,
         additional_fields: dict[str, t.Any] | None = None,
     ) -> None:
         super().__init__()
-        self._set_optstrs(
-            DATA_TYPE=DATA_TYPE,
-            authentication_mech=authentication_mech,
-            authenticator=authenticator,
-        )
-        self._set_optbools(uda_checksum_support=uda_checksum_support)
-        if additional_fields is not None:
-            self.update(additional_fields)
+        self["DATA_TYPE"] = DATA_TYPE
+        self["authentication_mech"] = authentication_mech
+        self["authenticator"] = authenticator
+        self["uda_checksum_support"] = uda_checksum_support
+        self.update(additional_fields or {})
