@@ -1,23 +1,29 @@
 from ._clientinfo import GlobusClientInfo
+from .caller_info import RequestCallerInfo
 from .encoders import FormRequestEncoder, JSONRequestEncoder, RequestEncoder
 from .requests import RequestsTransport
 from .retry import (
     RetryCheck,
+    RetryCheckCollection,
     RetryCheckFlags,
     RetryCheckResult,
-    RetryCheckRunner,
     RetryContext,
     set_retry_check_flags,
 )
+from .retry_check_runner import RetryCheckRunner
+from .retry_config import RetryConfig
 
 __all__ = (
     "RequestsTransport",
+    "RequestCallerInfo",
     "RetryCheck",
+    "RetryCheckCollection",
     "RetryCheckFlags",
     "RetryCheckResult",
     "RetryCheckRunner",
     "set_retry_check_flags",
     "RetryContext",
+    "RetryConfig",
     "RequestEncoder",
     "JSONRequestEncoder",
     "FormRequestEncoder",
