@@ -1,7 +1,7 @@
 import urllib.parse
 
-from globus_sdk._testing import get_last_request, load_response
-from globus_sdk.scopes import MutableScope
+from globus_sdk.scopes import Scope
+from globus_sdk.testing import get_last_request, load_response
 
 
 def test_oauth2_client_credentials_tokens(auth_client):
@@ -14,10 +14,10 @@ def test_oauth2_client_credentials_tokens(auth_client):
     )
 
 
-def test_oauth2_client_credentials_tokens_can_accept_mutable_scope_object(auth_client):
+def test_oauth2_client_credentials_tokens_can_accept_scope_object(auth_client):
     meta = load_response(auth_client.oauth2_client_credentials_tokens).metadata
 
-    response = auth_client.oauth2_client_credentials_tokens(MutableScope(meta["scope"]))
+    response = auth_client.oauth2_client_credentials_tokens(Scope(meta["scope"]))
     assert (
         response.by_resource_server[meta["resource_server"]]["access_token"]
         == meta["access_token"]
