@@ -2,7 +2,7 @@ import urllib.parse
 
 import pytest
 
-from globus_sdk._testing import get_last_request, load_response
+from globus_sdk.testing import get_last_request, load_response
 
 
 def test_oauth2_get_dependent_tokens(auth_client):
