@@ -4,7 +4,7 @@ import uuid
 
 import pytest
 
-from globus_sdk._testing import load_response
+from globus_sdk.testing import load_response
 
 
 @pytest.mark.parametrize(
