@@ -1,7 +1,7 @@
 import pytest
 
 from globus_sdk import GlobusSDKUsageError
-from globus_sdk._testing import load_response
+from globus_sdk.testing import load_response
 
 
 def test_get_scopes(service_client):
