@@ -1,5 +1,5 @@
 import globus_sdk
-from globus_sdk._testing import load_response
+from globus_sdk.testing import load_response
 
 
 def test_get_result_amqp_url(compute_client_v2: globus_sdk.ComputeClientV2):
